@@ -274,7 +274,9 @@ class IDACController:
             if response.status_code == 404:
                 # old controller, no support for auth/token API, ignore :)
                 logger.debug("Looks like controller doesn't support dCloud session auth. Ignoring")
-                return ""
+                if use_as_auth:
+                    self.auth = "empty_token"
+                return "empty_token"
             response.raise_for_status()
             json_body = ujson.loads(response.text)
             if isinstance(json_body, dict) and json_body.get("token", None):
