@@ -8,7 +8,14 @@ from idac_sdk import (
     SessionData,
 )
 from idac_sdk.cli.lib._controller_options import _controller_options, with_controller
-from idac_sdk.cli.lib._helpers import add_options, filter_dict, parse_data, parse_json
+from idac_sdk.cli.lib._helpers import (
+    add_options,
+    filter_dict,
+    parse_data,
+    parse_json,
+    _debug_options,
+    set_logger_level,
+)
 
 
 @click.group()
@@ -18,6 +25,7 @@ def commands():
 
 @commands.command(short_help="execute a recipe")
 @add_options(_controller_options)
+@add_options(_debug_options)
 @click.option(
     "--no-session-xml",
     is_flag=True,
@@ -70,6 +78,7 @@ async def create(controller, recipe_path, recipe_name, out_path, **kwargs):
     RECIPE_PATH - path to the recipe
     RECIPE_NAME - name of the recipe
     """
+    set_logger_level(kwargs.get("debug", False))
 
     # remove empty params
     filtered = filter_dict(kwargs, lambda el: el[1] is not None)
