@@ -3,7 +3,11 @@ from jsonpath_ng import parse
 
 from idac_sdk import IDACRequestAsync
 from idac_sdk.cli.lib._controller_options import _controller_options, with_controller
-from idac_sdk.cli.lib._helpers import add_options
+from idac_sdk.cli.lib._helpers import (
+    add_options,
+    _debug_options,
+    set_logger_level,
+)
 
 
 @click.group()
@@ -13,6 +17,7 @@ def commands():
 
 @commands.command(short_help="get state of a request")
 @add_options(_controller_options)
+@add_options(_debug_options)
 @click.option(
     "--out-path",
     multiple=True,
@@ -22,10 +27,12 @@ def commands():
 )
 @click.argument("request_id")
 @with_controller
-async def state(controller, request_id, out_path):
+async def state(controller, request_id, out_path, **kwargs):
     """Get JSON state object of a request
 
     REQUEST_ID - id/uuid of the request"""
+    set_logger_level(kwargs.get("debug", False))
+
     req = IDACRequestAsync(uuid=request_id, controller=controller)
     state = await req.get_state()
     if out_path:
@@ -42,10 +49,12 @@ async def state(controller, request_id, out_path):
 @add_options(_controller_options)
 @click.argument("request_id")
 @with_controller
-async def status(controller, request_id):
+async def status(controller, request_id, **kwargs):
     """Get current status of a request
 
     REQUEST_ID - id/uuid of the request"""
+    set_logger_level(kwargs.get("debug", False))
+
     req = IDACRequestAsync(uuid=request_id, controller=controller)
     state = await req.get_state()
     click.echo(state.status)
