@@ -3,6 +3,8 @@ from enum import Enum, unique
 
 @unique
 class IDACRequestType(Enum):
+    """iDAC request types"""
+
     SIMPLE = 0
     STATELESS = 1
     STATEFUL = 2
@@ -10,6 +12,8 @@ class IDACRequestType(Enum):
 
 @unique
 class IDACRequestStatus(Enum):
+    """iDAC request statuses"""
+
     active = "active"
     queued = "queued"
     toBeDeleted = "toBeDeleted"
@@ -28,6 +32,8 @@ class IDACRequestStatus(Enum):
 
 @unique
 class IDACAuthType(Enum):
+    """iDAC authentication types"""
+
     NONE = 0
     BASIC = 1
     BEARER = 2
